@@ -271,7 +271,7 @@ typedef struct st_partition_part_key_multi_range_hld
   /* Owner object */
   ha_partition *partition;
 
-  /* id of the the partition this structure is for */
+  /* id of the partition this structure is for */
   uint32 part_id;
 
   /* Current range we're iterating through */
@@ -322,7 +322,6 @@ private:
     and if clustered pk, [0]= current index, [1]= pk, [2]= NULL
   */
   KEY *m_curr_key_info[3];              // Current index
-  uchar *m_rec0;                        // table->record[0]
   const uchar *m_err_rec;               // record which gave error
   QUEUE m_queue;                        // Prio queue used by sorted read
 
@@ -469,11 +468,11 @@ public:
   {
     return m_is_clone_of;
   }
-  virtual part_id_range *get_part_spec()
+  part_id_range *get_part_spec()
   {
     return &m_part_spec;
   }
-  virtual uint get_no_current_part_id()
+  uint get_no_current_part_id()
   {
     return NO_CURRENT_PART_ID;
   }
@@ -553,7 +552,8 @@ public:
              HA_CREATE_INFO *create_info) override;
   int create_partitioning_metadata(const char *name,
                                    const char *old_name,
-                                   chf_create_flags action_flag)
+                                   chf_create_flags action_flag,
+                                   bool ignore_delete_error)
     override;
   bool check_if_updates_are_ignored(const char *op) const override;
   void update_create_info(HA_CREATE_INFO *create_info) override;
@@ -576,6 +576,17 @@ public:
   {
     m_file[part_id]->update_create_info(create_info);
   }
+
+  void column_bitmaps_signal() override
+  {
+    for (uint i= bitmap_get_first_set(&m_opened_partitions);
+        i < m_tot_parts;
+        i= bitmap_get_next_set(&m_opened_partitions, i))
+    {
+      m_file[i]->column_bitmaps_signal();
+    }
+  }
+
 private:
   int copy_partitions(ulonglong * const copied, ulonglong * const deleted);
   void cleanup_new_partition(uint part_count);
@@ -916,7 +927,7 @@ public:
   /* Range iterator structure to be supplied to partitions */
   RANGE_SEQ_IF m_part_seq_if;
 
-  virtual int multi_range_key_create_key(
+  int multi_range_key_create_key(
     RANGE_SEQ_IF *seq,
     range_seq_t seq_it
   );
@@ -1384,7 +1395,7 @@ public:
 private:
   int reset_auto_increment(ulonglong value) override;
   int update_next_auto_inc_val();
-  virtual void lock_auto_increment()
+  void lock_auto_increment()
   {
     /* lock already taken */
     if (auto_increment_safe_stmt_log_lock)
@@ -1396,7 +1407,7 @@ private:
       auto_increment_lock= TRUE;
     }
   }
-  virtual void unlock_auto_increment()
+  void unlock_auto_increment()
   {
     /*
       If auto_increment_safe_stmt_log_lock is true, we have to keep the lock.
@@ -1409,7 +1420,7 @@ private:
       part_share->unlock_auto_inc();
     }
   }
-  virtual void set_auto_increment_if_higher(Field *field)
+  void set_auto_increment_if_higher(Field *field)
   {
     ulonglong nr= (((Field_num*) field)->unsigned_flag ||
                    field->val_int() > 0) ? field->val_int() : 0;
